@@ -91,6 +91,25 @@ test_that("La plus ca meme la plus ca meme: medicare levy", {
   expect_equal(new_tax2, original)
 })
 
+test_that("La plus ca meme la plus ca meme: LITO", {
+  skip_if_not_installed("taxstats"); skip_on_cran()
+  library(taxstats)
+  sample_file_1314_copy <- copy(sample_file_1314)
+  
+  original <- 
+    income_tax(sample_file_1314_copy$Taxable_Income,
+               fy.year = "2013-14",
+               .dots.ATO = copy(sample_file_1314_copy))
+  
+  new_tax2 <-
+    model_income_tax(copy(sample_file_1314_copy),
+                     baseline_fy = "2013-14",
+                     lito_taper = 0.015, 
+                     return. = "tax")
+  
+  expect_equal(new_tax2, original)
+})
+
 test_that("Increase in a rate results in more tax", {
   skip_if_not_installed("taxstats"); skip_on_cran()
   library(taxstats)
@@ -364,12 +383,14 @@ test_that("Medicare families", {
   s1617_modelled <-
     model_income_tax(s1617, 
                      "2016-17",
+                     # ordinary_tax_rates = c(0, 0.19, 0.325, 0.37, 0.47), # temp budget repair levy
                      medicare_levy_lower_family_threshold = 35000,
                      medicare_levy_upper_family_threshold = 43750,
                      return. = "tax")
   single_idx <- which(s1617$Spouse_adjusted_taxable_inc == 0)
   expect_equal(s1617_orig$orig_tax[single_idx],
-               s1617_modelled[single_idx])
+               s1617_modelled[single_idx], 
+               tol = 1)
   
 })
 
@@ -484,8 +505,11 @@ test_that("Elasticity of taxable income", {
                      medicare_levy_lower_threshold = 22499,
                      medicare_levy_upper_threshold = 30e3, 
                      medicare_levy_upper_sapto_threshold = 44984,
+                     medicare_levy_lower_sapto_threshold = 33737,
                      medicare_levy_upper_family_threshold = 48001,
+                     medicare_levy_lower_family_threshold = 36000,
                      medicare_levy_upper_family_sapto_threshold = 62621,
+                     medicare_levy_lower_family_sapto_threshold = 46965,
                      return. = "sample_file") %>%
     .[, .(Ind,
           Taxable_Income,
@@ -499,7 +523,10 @@ test_that("Elasticity of taxable income", {
                      medicare_levy_rate = 0.025,
                      medicare_levy_upper_threshold = 30e3, 
                      medicare_levy_lower_threshold = 22499,
+                     medicare_levy_lower_sapto_threshold = 33737,
+                     medicare_levy_lower_family_threshold = 36000,
                      medicare_levy_upper_sapto_threshold = 44984,
+                     medicare_levy_lower_family_sapto_threshold = 46965,
                      medicare_levy_upper_family_threshold = 48001,
                      medicare_levy_upper_family_sapto_threshold = 62621,
                      return = "sample_file")
@@ -517,8 +544,11 @@ test_that("Elasticity of taxable income", {
                      medicare_levy_rate = 0.025,
                      medicare_levy_upper_threshold = 30e3, 
                      medicare_levy_lower_threshold = 22499,
+                     medicare_levy_lower_sapto_threshold = 33737,
                      medicare_levy_upper_sapto_threshold = 44984,
+                     medicare_levy_lower_family_threshold = 36000,
                      medicare_levy_upper_family_threshold = 48001,
+                     medicare_levy_lower_family_sapto_threshold = 46965,
                      medicare_levy_upper_family_sapto_threshold = 62621,
                      return. = "sample_file")
   elasticity_1.0 <- 
@@ -583,6 +613,114 @@ test_that("Elasticity 0 vs 1", {
   expect_true(all(result$new_tax_E0 > result$new_tax_e1))
 })
 
+test_that("Lamington", {
+  skip_on_cran()
+  skip_if_not_installed("taxstats", minimum_version = "0.0.5")
+  skip_if_not_installed("fst", minimum_version = "0.8.4")
+  temp.fst <- "~/SampleFile1819/sample_file_1819.fst"
+  library(data.table)
+  library(hutils)
+  library(magrittr)
+  if (!exists("sample_file_1819") || !is.data.table(sample_file_1819)) {
+    if (!file.exists("~/SampleFile1819/sample_file_1819.fst")) {
+      temp.fst <- tempfile(fileext = ".fst")
+      download.file('https://github.com/HughParsonage/SampleFile1819/raw/master/sample_file_1819.fst',
+                    mode = "wb", 
+                    destfile = temp.fst,
+                    quiet = TRUE)
+    }
+    sample_file_1819 <- fst::read_fst(temp.fst, as.data.table = TRUE)
+  }
+  
+  skip_if_not(exists("sample_file_1819"))
+  if (!"Ind" %in% names(sample_file_1819)) {
+    sample_file_1819[, Ind := .I]
+  }
+  
+  
+  s1819_Budget2018_lamington <- 
+    model_income_tax(sample_file_1819,
+                     baseline_fy = "2017-18",
+                     ordinary_tax_rates = c(0, 0.19, 0.325, 0.37, 0.45),
+                     ordinary_tax_thresholds = c(0, 18200, 37e3, 90e3, 180e3),
+                     Budget2018_lamington = TRUE) %>%
+    .[, .(Taxable_Income, new_tax, baseline_tax)] %>%
+    .[, delta := as.integer(new_tax) - as.integer(baseline_tax)] %>%
+    setkey(Taxable_Income) %>%
+    .[]
+  # https://budget.gov.au/2018-19/content/incometax.html
+  expect_equal(coalesce(as.double(s1819_Budget2018_lamington[.(c(23000, 37000, 50e3, 91e3, 200e3)), mult="first"][["delta"]]),
+                        c(-200, -200, -530, -650, -135)),
+               c(-200, -200, -530, -650, -135))
+  
+})
+
+test_that("Clear columns", {
+  skip_on_cran()
+  skip_if_not_installed("taxstats")
+  library(taxstats)
+  s1314 <- as.data.table(sample_file_1314)
+  s1314[, new_tax := 1][, baseline_tax := 2]
+  res <- model_income_tax(s1314, "2013-14", clear_tax_cols = TRUE)
+  expect_true(res[, max(new_tax)] > 1)
+})
+
+test_that("sample_file.int", {
+  skip_on_cran()
+  skip_if_not_installed("taxstats")
+  library(taxstats)
+  s1314 <- as.data.table(sample_file_1314)
+  res <- model_income_tax(s1314, "2013-14", return. = "sample_file.int")
+  expect_identical(res[["new_tax"]], res[["baseline_tax"]])
+})
+
+test_that("lito_multi", {
+  skip_on_cran()
+  skip_if_not_installed("taxstats")
+  library(taxstats)
+  s1314 <- as.data.table(sample_file_1314)
+  base <- model_income_tax(s1314, "2013-14")
+  
+  expect_error(model_income_tax(s1314, "2013-14",
+                                lito_max_offset = 445, 
+                                lito_multi = list()), 
+               regexp = "`lito_multi` is not NULL, yet neither is `lito_max_offset`.", 
+               fixed = TRUE)
+  expect_error(model_income_tax(s1314, "2013-14",
+                                lito_taper = 445, 
+                                lito_multi = list()), 
+               regexp = "`lito_multi` is not NULL, yet neither is `lito_taper`.", 
+               fixed = TRUE)
+  expect_error(model_income_tax(s1314, "2013-14",
+                                lito_min_bracket = 445, 
+                                lito_multi = list()), 
+               regexp = "`lito_multi` is not NULL, yet neither is `lito_min_bracket`.", 
+               fixed = TRUE)
+  expect_error(model_income_tax(s1314, "2013-14",
+                                lito_multi = 445), 
+               regexp = "`lito_multi` had class numeric. Must be a list.", 
+               fixed = TRUE)
+  expect_error(model_income_tax(s1314, "2013-14",
+                                lito_multi = list()), 
+               regexp = "`lito_multi` had no names.", 
+               fixed = TRUE)
+  expect_error(model_income_tax(s1314, "2013-14",
+                                lito_multi = list(a = 1, b = 2)), 
+               regexp = "Set the names as 'x' and 'y'.", 
+               fixed = TRUE)
+  
+  mult <- model_income_tax(s1314, "2013-14", 
+                           lito_multi = list(x = c(-Inf, 37e3, 200e3/3, Inf), 
+                                             y = c(445, 445, 0, 0)), 
+                           return. = "sample_file.int")
+  
+  
+  expect_identical(mult[["new_tax"]], mult[["baseline_tax"]])
+  
+})
+
+
+
 
 
 
